Pipettor Library
================


Function Interface
------------------
.. autofunction:: pipettor.run
   :noindex:
.. autofunction:: pipettor.runout
   :noindex:
.. autofunction:: pipettor.runlex
   :noindex:
.. autofunction:: pipettor.runlexout
   :noindex:

Pipeline Classes
----------------
.. autoclass:: pipettor.Pipeline
   :noindex:
.. autoclass:: pipettor.Popen
   :noindex:
                  

Process I/O Classes
-------------------
.. autoclass:: pipettor.DataReader
   :noindex:
.. autoclass:: pipettor.DataWriter
   :noindex:
.. autoclass:: pipettor.File
   :noindex:


Logging Control
---------------
.. autofunction:: pipettor.setDefaultLogger
   :noindex:
.. autofunction:: pipettor.getDefaultLogger
   :noindex:

Exceptions
----------
.. autoclass:: pipettor.PipettorException
   :noindex:
.. autoclass:: pipettor.ProcessException
   :noindex:
